@@ -4,6 +4,7 @@
 WeightDialog::WeightDialog(QWidget *parent) :
         QDialog(parent)
 {
+    qDebug () << "WeightDialog::WeightDialog 1";
     setAttribute(Qt::WA_Maemo5StackedWindow);
     setAttribute(Qt::WA_Maemo5PortraitOrientation);
 
@@ -12,17 +13,19 @@ WeightDialog::WeightDialog(QWidget *parent) :
 
     QHBoxLayout *hLayout = new QHBoxLayout();
     QVBoxLayout *buttonLayout = new QVBoxLayout();
-
+    qDebug () << "WeightDialog::WeightDialog 2";
     modelReps = new QStandardItemModel(this);
     for (int i = 1; i <= 25; i++)
         modelReps->appendRow(new QStandardItem(tr("%1").arg(i)));
 
+    qDebug () << "WeightDialog::WeightDialog 3";
     btnReps = new QMaemo5ValueButton("Reps");
     btnReps->setValueLayout(QMaemo5ValueButton::ValueUnderText);
     selectorReps = new QMaemo5ListPickSelector;
     selectorReps->setModel(modelReps);
     btnReps->setPickSelector(selectorReps);
 
+    qDebug () << "WeightDialog::WeightDialog 4";
 
     btnVar = new QMaemo5ValueButton();
     btnVar->setValueLayout(QMaemo5ValueButton::ValueUnderText);
@@ -34,7 +37,7 @@ WeightDialog::WeightDialog(QWidget *parent) :
     buttonLayout->addWidget(btnVar);
     hLayout->addLayout(buttonLayout);
 
-
+    qDebug () << "WeightDialog::WeightDialog 5";
 
     radioEasy = new QRadioButton("Easy");
     radioOK = new QRadioButton("Perfect");
@@ -53,30 +56,27 @@ WeightDialog::WeightDialog(QWidget *parent) :
     setLayout(hLayout);
     xml = new XML();
     //load();
+    qDebug () << "WeightDialog::WeightDialog 6";
     connect(btnSave, SIGNAL(clicked()),this,SLOT(save()));
+    qDebug () << "WeightDialog::WeightDialog 7";
 }
 
 void WeightDialog::load(QString name, QString grp, QString currentSet)
 {
+    qDebug () << "WeightDialog::load 1";
     btnVar->setText("Weight");
-    QList <QString> list;
 
     exName = name;
     group = grp;
     set = currentSet;
-
+    qDebug () << "WeightDialog::load 2";
     for (int i = 1; i < 200; i++)
         modelVar->appendRow(new QStandardItem(tr("%1").arg(i)+ "kg"));
 
-    list = xml->openEx(name);
-
-
-
-
-
+    qDebug () << "WeightDialog::load 3";
     setWindowTitle("Save weight (set:" + currentSet + ")");
 
-
+    qDebug () << "WeightDialog::load 4";
 }
 
 void WeightDialog::loadCardio(QString name, QString m, QString s)
@@ -102,7 +102,9 @@ void WeightDialog::loadCardio(QString name, QString m, QString s)
 
 void WeightDialog::save()
 {
+    qDebug () << "WeightDialog::save 1";
     QString status, weight;
+
     if(radioOK->isChecked())
         status = "perfect";
     else if(radioEasy->isChecked())
@@ -112,28 +114,39 @@ void WeightDialog::save()
     else
         return;
 
+    qDebug () << "WeightDialog::save 2";
+
     if(btnReps->valueText() == "")
         return;
     else if(btnVar->valueText() == "")
         return;
 
+    qDebug () << "WeightDialog::save 3";
     weight = btnVar->valueText();
 
     if(group == "Cardio")
     {
         reps = min + ":" + sec;
         xml->updateLastDistance(exName, weight, min, sec, status);
+        qDebug () << "WeightDialog::save 4";
     }
     else
     {
         reps = btnReps->valueText();
     }
-
+    qDebug () << "WeightDialog::save 5";
     if(set.toInt() == 1)
+    {
         xml->saveFirstSet(group, exName, weight, reps, status);
+        qDebug () << "WeightDialog::save 6";
+    }
     else
+    {
         xml->updateHistory(exName,set,weight,reps,status);
+        qDebug () << "WeightDialog::save 7";
+    }
 
     emit next();
+    qDebug () << "WeightDialog::save 8";
     this->hide();
 }
